@@ -121,8 +121,7 @@ class ModelsTests(DatabaseTests):
         db.session.add(user)
         db.session.commit()
         test_user = UserMixin.query.get(1)
-        roles = [role.name for role in test_user.roles]
-        self.assertEqual(set(new_roles), set(roles))
+        self.assertItemsEqual(new_roles, test_user.roles)
 
     def test_add_roles_with_existing_roles(self):
         user = UserMixin(default_role=None)
@@ -135,8 +134,7 @@ class ModelsTests(DatabaseTests):
         db.session.add(user)
         db.session.commit()
         test_user = UserMixin.query.get(1)
-        roles = [role.name for role in test_user.roles]
-        self.assertEqual(set(new_roles), set(roles))
+        self.assertItemsEqual(new_roles, test_user.roles)
 
     def test_remove_roles(self):
         user = UserMixin()
@@ -149,8 +147,7 @@ class ModelsTests(DatabaseTests):
         db.session.add(user)
         db.session.commit()
         test_user = UserMixin.query.get(1)
-        roles = [role.name for role in test_user.roles]
-        self.assertEqual(set(roles), set(['superadmin']))
+        self.assertItemsEqual(test_user.roles, ['superadmin'])
 
     def test_add_abilities_with_nonexisting_abilities(self):
         role = Role('admin')
@@ -160,7 +157,7 @@ class ModelsTests(DatabaseTests):
         db.session.commit()
         test_role = Role.query.get(1)
         abilities = [ability.name for ability in test_role.abilities]
-        self.assertEqual(set(new_abilities), set(abilities))
+        self.assertItemsEqual(new_abilities, abilities)
 
     def test_add_abilities_with_existing_abilities(self):
         role = Role('admin')
@@ -174,7 +171,7 @@ class ModelsTests(DatabaseTests):
         db.session.commit()
         test_role = Role.query.get(1)
         abilities = [ability.name for ability in test_role.abilities]
-        self.assertEqual(set(new_abilities), set(abilities))
+        self.assertItemsEqual(new_abilities, abilities)
 
     def test_remove_abilities(self):
         role = Role('admin')
@@ -188,7 +185,7 @@ class ModelsTests(DatabaseTests):
         db.session.commit()
         test_role = Role.query.get(1)
         abilities = [ability.name for ability in test_role.abilities]
-        self.assertEqual(set(abilities), set(['create_users']))
+        self.assertItemsEqual(abilities, ['create_users'])
 
 
 class DecoratorsTests(DatabaseTests):
